@echo off

rem Script for launching VBS scripts for removing and re-adding
rem Videos from/to Extras in a GameBase64 Collection.
rem
rem Use this script instead of double-clicking on the VBS files,
rem because you probably encounter problems when using a 64 bit OS.
rem
rem (c) 2023 by K.C.

setlocal enabledelayedexpansion

rem Display Title Screen
call :TitleScreen

rem Set Environment Variables
set DelGVA=GB64_delete_gamevidoearchive.vbs
set DelLongplay=GB64_delete_longplay.vbs
set DelOther=GB64_delete_other.vbs
set AddGVA=GB64_add_gamevidoearchive.vbs
set AddLongplay=GB64_add_longplay.vbs
set AddOther=GB64_add_other.vbs
set VBSArgument=.\GBC_V19.MDB
set TempFile=%Temp%\__GBAddRemoveVideosTempFile___.txt

rem Verify required files and end script if not all files are found
set VBSNotFound=False
if not exist !DelGVA! set VBSNotFound=True
if not exist !DelLongplay! set VBSNotFound=True
if not exist !DelOther! set VBSNotFound=True
if not exist !AddGVA! set VBSNotFound=True
if not exist !AddLongplay! set VBSNotFound=True
if not exist !AddOther! set VBSNotFound=True
if [!VBSNotFound!]==[True] (
   echo *** ERROR ***
   echo One or more required VBS script files were not found.
   echo The following files should exist in the same folder as this script:
   echo.
   echo !DelGVA!
   echo !DelLongplay!
   echo !DelOther!
   echo !AddGVA!
   echo !AddLongplay!
   echo !AddOther!
   pause
   exit /b
)

rem Detect Windows and ODBC driver version
Set Windows3264=64
Set Office3264=64
reg query HKLM\Software\WOW6432Node > nul 2> nul
if errorlevel 1 (
   set Windows3264=32
   set Office3264=32
) else (
   set Windows3264=64
   reg query "HKLM\SOFTWARE\WOW6432Node\ODBC\ODBCINST.INI\Microsoft Access Driver (*.mdb, *.accdb)" > nul 2> nul
   if errorlevel 1 (
      reg query "HKLM\SOFTWARE\ODBC\ODBCINST.INI\Microsoft Access Driver (*.mdb, *.accdb)" > nul 2> nul
      if errorlevel 1 (
         set Office3264=NotInstalled
      ) else (
         set Office3264=64
      )
   ) else (
      set Office3264=32
   )
)

rem End script if ODBC driver cannot be found
if [!Office3264!]==[NotInstalled] (
   echo.
   call :ODBCError
   exit /b
)


rem Display detected Windows and ODBC driver version
echo.
echo.
echo Detected Windows version:            !Windows3264! bit
echo Detected Office/ODBC Driver version: !Office3264! bit
echo.
echo.

rem Optionally modify detected settings
:ChangeWinOffBitMenu
echo|set /p dummy=Do you want to make changes to the settings above? 
set ChangeBit=N
set /p ChangeBit= [Y,N, Enter=N] :
set ChangeBit=!ChangeBit:~0,1!
if /i [!ChangeBit!]==[N] goto NoBitChanges
if /i [!ChangeBit!]==[Y] (
   call :ChangeWindowsVersion
   if [!Windows3264!]==[64] (
      call :ChangeOfficeVersion
   ) else (
      set Office3264=32
   )
   goto NoBitChanges
)
goto ChangeWinOffBitMenu

:NoBitChanges
rem Display the Title Screen
call :TitleScreen
echo.
echo Running script for !Windows3264! bit version of Windows and !Office3264! bit version of Office.
echo.

rem store the correct registry key for ODBC driver in a variable
if [!Windows3264!]==[64] (
   if [!Office3264!]==[32] (
      set ODBCRegKey="HKLM\SOFTWARE\WOW6432Node\ODBC\ODBCINST.INI\Microsoft Access Driver (*.mdb, *.accdb)"
   ) else (
      set ODBCRegKey="HKLM\SOFTWARE\ODBC\ODBCINST.INI\Microsoft Access Driver (*.mdb, *.accdb)"
   )
) else (
   set ODBCRegKey="HKLM\SOFTWARE\ODBC\ODBCINST.INI\Microsoft Access Driver (*.mdb, *.accdb)"
)

rem Store the correct version of CSCRIPT.EXE in a variable
if [!Windows3264!]==[64] (
   if [!Office3264!]==[32] (
      set CScriptPath=%SYSTEMROOT%\SysWOW64\cscript.exe
   ) else (
      set CScriptPath=%SYSTEMROOT%\System32\cscript.exe
   )
)
         
rem Display the Main Menu
:MainMenu
echo 1 - Remove all videos from the GB64 Collection
echo 2 - Re-add the videos to the GB64 Collection
echo 3 - Change installed Windows and Office/ODBC Driver version
echo 4 - Exit this menu
echo.

:MainMenuLoop
set /p Choice=Your choice [1, 2, 3, 4]: 
if [!Choice!]==[4] exit /b
for %%a in (1 2 3) do if [!Choice!]==[%%a] call :Choice!Choice!
goto NoBitChanges

:Choice1
   call :TitleScreen
   echo.
   reg query !ODBCRegKey! > nul 2> nul
   if errorlevel 1 (
      call :ODBCError
      exit /b
   )
   echo|set/p Dummy=Deleting Game Video Archive videos...
   !CScriptPath! !DelGVA! !VBSArgument! > nul 2> !TempFile!
   for %%i in ("!TempFile!") do set /a FileSize=%%~zi
   if !FileSize! EQU 0 (
      echo ..........Completed
   ) else (
     echo ..........*** FAILED ***
     type "!TempFile!"
   )
   if exist !TempFile! del !TempFile!
   echo|set /p Dummy=Deleting Longplay videos...
   !CScriptPath! !DelLongplay! !VBSArgument! > nul 2> !TempFile!
   for %%i in ("!TempFile!") do set /a FileSize=%%~zi
   if !FileSize! EQU 0 (
      echo ....................Completed
   ) else (
     echo ....................*** FAILED ***
     type "!TempFile!"
   )
   if exist !TempFile! del !TempFile!
   echo|set /p Dummy=Deleting old Longplay videos...
   !CScriptPath! !DelOther! !VBSArgument! > nul 2> !TempFile!
   for %%i in ("!TempFile!") do set /a FileSize=%%~zi
   if !FileSize! EQU 0 (
      echo ................Completed
   ) else (
     echo ................*** FAILED ***
     type "!TempFile!"
   )
   if exist !TempFile! del !TempFile!
   pause
   exit /b

:Choice2
   call :TitleScreen
   echo.
   reg query !ODBCRegKey! > nul 2> nul
   if errorlevel 1 (
      call :ODBCError
      exit /b
   )
   echo|set /p Dummy=Adding Game Video Archive videos...
   !CScriptPath! !AddGVA! !VBSArgument! > nul 2> !TempFile!
   for %%i in ("!TempFile!") do set /a FileSize=%%~zi
   if !FileSize! EQU 0 (
      echo ............Completed
   ) else (
     echo ............*** FAILED ***
     type "!TempFile!"
   )
   if exist !TempFile! del !TempFile!
   echo|set /p Dummy=Adding Longplay videos...
   !CScriptPath! !AddLongplay! !VBSArgument! > nul 2> !TempFile!
   for %%i in ("!TempFile!") do set /a FileSize=%%~zi
   if !FileSize! EQU 0 (
      echo ......................Completed
   ) else (
     echo ......................*** FAILED ***
     type "!TempFile!"
   )
   if exist !TempFile! del !TempFile!
   echo|set /p Dummy=Adding old Longplay videos...
   !CScriptPath! !AddOther! !VBSArgument! > nul 2> !TempFile!
   for %%i in ("!TempFile!") do set /a FileSize=%%~zi
   if !FileSize! EQU 0 (
      echo ..................Completed
   ) else (
     echo ..................*** FAILED ***
     type "!TempFile!"
   )
   if exist !TempFile! del !TempFile!
   pause
   exit /b

:Choice3
   call :ChangeWindowsVersion
   if [!Windows3264!]==[64] (
      call :ChangeOfficeVersion
   ) else (
      set Office3264=32
   )
   exit /b

:ChangeWindowsVersion
echo.
echo|set /p dummy=Windows version             
set /p Windows3264= [32, 64, Enter for !Windows3264!] :
if [!Windows3264!]==[32] exit /b
if [!Windows3264!]==[64] exit /b
goto ChangeWindowsVersion
exit /b

:ChangeOfficeVersion
echo|set /p dummy=Office/ODBC Driver version  
set /p Office3264= [32, 64, Enter for !Office3264!] :
if [!Office3264!]==[32] exit /b
if [!Office3264!]==[64] exit /b
goto ChangeOfficeVersion
exit /b

:ODBCError
   echo The ODBC driver for Microsoft Access was not found. This driver is included in
   echo Microsoft Office. Either Microsoft Office is not installed, or an incorrect
   echo version of Microsoft Windows or Microsoft Office is detected.
   echo.
   echo If Microsoft Office is installed, verify and modify the Windows- and Office
   echo settings with menu option 3.
   echo If Microsoft Office is not installed, download and install the
   echo Microsoft Access Database Engine 2010 Redistributable from
   echo https://www.microsoft.com/en-us/download/details.aspx?id=13255
   pause
   exit /b

:TitleScreen
cls
echo ~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~
echo "             _       _     _    ______                                       "
echo "            / \   __| | __| |  / /  _ \ ___ _ __ ___   _____   _____         "
echo "           / _ \ / _\ |/ _\ | / /| |_) / _ \  _ \ _ \ / _ \ \ / / _ \        "
echo "          / ___ \ (_| | (_| |/ / |  _ <  __/ | | | | | (_) \ V /  __/        "
echo "         /_/   \_\__,_|\__,_/_/  |_| \_\___|_| |_| |_|\___/ \_/ \___|        "
echo "           ____ ____   __   _  _           _     _                           "
echo "          / ___| __ ) / /_ | || |   __   _(_) __| | ___  ___  ___            "
echo "         | |  _|  _ \|  _ \| || |_  \ \ / / |/ _\ |/ _ \/ _ \/ __|           "
echo "         | |_| | |_) | (_) |__   _|  \ V /| | (_| |  __/ (_) \__ \           "
echo "          \____|____/ \___/   |_|     \_/ |_|\__,_|\___|\___/|___/           "
echo "                                                                             "
echo " (c) 2023 The GB64 Team                              (Version 1.9 - GBC_V19) "
echo ~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~
exit /b